@@ -1,9 +1,12 @@
-use fixed2float::{to_Q, to_float, to_float_str, FixedPoint, Fx, Q};
+use fixed2float::{to_Fx, to_Q, to_float, to_float_str, FixedPoint, Fx, Q};
 
 fn main() {
     let bits = "1010000010110000";
     let (m, n) = (1, 15);
 
+    let b1 = to_Q(0.0, 1, 5, true).unwrap();
+    println!("{b1:?}");
+
     let x = to_float_str(bits, m, n);
     println!("bits = {} -> {:?}", bits, x);
 
@@ -25,4 +28,7 @@ fn main() {
 
     // let fp1_sliced = fp1.index(7..0);
     // println!("{:?}", fp1_sliced);
+
+    let fp33 = to_Fx(0.000244140625, 0, 12, true);
+    println!("{fp33:?}");
 }
